@@ -13,7 +13,7 @@ def download_file_from_google_drive(destination):
     def save_response_content(response, destination):
         CHUNK_SIZE = 32768
 
-        with open(destination, "wb") as f:
+        with open(destination, "wb+") as f:
             for chunk in response.iter_content(CHUNK_SIZE):
                 if chunk: # filter out keep-alive new chunks
                     f.write(chunk)
